import { AccountAddress, ChainAddress, ChainsConfig, Contracts, NativeAddress, Network, TokenAddress, TokenBridge, TokenId, Chain, Platform } from '@wormhole-foundation/connect-sdk';
import { Provider } from 'ethers';
import { TokenBridgeContract } from './ethers-contracts';
import { EvmChains, EvmPlatformType, EvmUnsignedTransaction } from '@wormhole-foundation/connect-sdk-evm';
import '@wormhole-foundation/connect-sdk-evm-core';
export declare class EvmTokenBridge<N extends Network, C extends EvmChains> implements TokenBridge<N, EvmPlatformType, C> {
    readonly network: N;
    readonly chain: C;
    readonly provider: Provider;
    readonly contracts: Contracts;
    readonly tokenBridge: TokenBridgeContract;
    readonly tokenBridgeAddress: string;
    readonly chainId: bigint;
    private constructor();
    static fromRpc<N extends Network>(provider: Provider, config: ChainsConfig<N, Platform>): Promise<EvmTokenBridge<N, EvmChains>>;
    isWrappedAsset(token: TokenAddress<C>): Promise<boolean>;
    getOriginalAsset(token: TokenAddress<C>): Promise<TokenId>;
    hasWrappedAsset(token: TokenId): Promise<boolean>;
    getWrappedAsset(token: TokenId<Chain>): Promise<NativeAddress<C>>;
    isTransferCompleted(vaa: TokenBridge.TransferVAA): Promise<boolean>;
    createAttestation(token: TokenAddress<C>): AsyncGenerator<EvmUnsignedTransaction<N, C>>;
    submitAttestation(vaa: TokenBridge.AttestVAA): AsyncGenerator<EvmUnsignedTransaction<N, C>>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, token: TokenAddress<C>, amount: bigint, payload?: Uint8Array): AsyncGenerator<EvmUnsignedTransaction<N, C>>;
    redeem(sender: AccountAddress<C>, vaa: TokenBridge.TransferVAA, unwrapNative?: boolean): AsyncGenerator<EvmUnsignedTransaction<N, C>>;
    getWrappedNative(): Promise<((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) extends infer T ? T extends ((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) ? T extends "Evm" ? WormholeNamespace.PlatformToNativeAddressMapping[T] : never : never : never>;
    private createUnsignedTx;
}
//# sourceMappingURL=tokenBridge.d.ts.map